summaryrefslogtreecommitdiff
path: root/src/sd-daemon.h
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2010-05-21 17:06:40 +0200
committerLennart Poettering <lennart@poettering.net>2010-05-21 17:06:40 +0200
commit88ce42f6944774788f610598fccdc6bab4283497 (patch)
treec6d9e98e8b800e0bede5fa9c384d4f55be20c505 /src/sd-daemon.h
parentdde770cfc6a287772a936be58b73adf9a6c334f5 (diff)
sd-daemon: verify socket family, too
Diffstat (limited to 'src/sd-daemon.h')
-rw-r--r--src/sd-daemon.h34
1 files changed, 18 insertions, 16 deletions
diff --git a/src/sd-daemon.h b/src/sd-daemon.h
index ab69364c26..e209af6489 100644
--- a/src/sd-daemon.h
+++ b/src/sd-daemon.h
@@ -73,24 +73,26 @@ int sd_listen_fds(int unset_environment);
int sd_is_fifo(int fd, const char *path);
/* Helper call for identifying a passed file descriptor. Returns 1 if
- * the file descriptor is a socket of the specified type (SOCK_DGRAM,
- * SOCK_STREAM, ...), 0 otherwise. If type is 0 a socket type check
- * will not be done and the call only verifies if the file descriptor
- * refers to a socket. If listening is > 0 it is verified that the
- * socket is in listening mode. (i.e. listen() has been called) If
- * listening is == 0 it is verified that the socket is not in
- * listening mode. If listening is < 0 no listening mode check is
- * done. Returns a negative errno style error code on failure. */
-int sd_is_socket(int fd, int type, int listening);
+ * the file descriptor is a socket of the specified family (AF_INET,
+ * ...) and type (SOCK_DGRAM, SOCK_STREAM, ...), 0 otherwise. If
+ * family is 0 a socket family check will not be done. If type is 0 a
+ * socket type check will not be done and the call only verifies if
+ * the file descriptor refers to a socket. If listening is > 0 it is
+ * verified that the socket is in listening mode. (i.e. listen() has
+ * been called) If listening is == 0 it is verified that the socket is
+ * not in listening mode. If listening is < 0 no listening mode check
+ * is done. Returns a negative errno style error code on failure. */
+int sd_is_socket(int fd, int family, int type, int listening);
/* Helper call for identifying a passed file descriptor. Returns 1 if
- * the file descriptor is an Internet socket (either AF_INET or
- * AF_INET6) of the specified type (SOCK_DGRAM, SOCK_STREAM, ...), 0
- * otherwise. If type is 0 a socket type check will not be done. If
- * port is 0 a socket port check will not be done. The listening flag
- * is used the same way as in sd_is_socket(). Returns a negative errno
- * style error code on failure. */
-int sd_is_socket_inet(int fd, int type, int listening, uint16_t port);
+ * the file descriptor is an Internet socket, of the specified family
+ * (either AF_INET or AF_INET6) of the specified type (SOCK_DGRAM,
+ * SOCK_STREAM, ...), 0 otherwise. If version is 0 a protocol version
+ * check is not done. If type is 0 a socket type check will not be
+ * done. If port is 0 a socket port check will not be done. The
+ * listening flag is used the same way as in sd_is_socket(). Returns a
+ * negative errno style error code on failure. */
+int sd_is_socket_inet(int fd, int family, int type, int listening, uint16_t port);
/* Helper call for identifying a passed file descriptor. Returns 1 if
* the file descriptor is an AF_UNIX socket of the specified type